/*
 *******************************************************************
 * Project code name "ORCA"
 * 日医標準レセプトソフト（JMA standard receipt software）
 * Copyright(C) 2002 JMA (Japan Medical Association)
 *
 * This program is part of "JMA standard receipt software".
 *
 *     This program is distributed in the hope that it will be useful
 * for further advancement in medical care, according to JMA Open
 * Source License, but WITHOUT ANY WARRANTY.
 *     Everyone is granted permission to use, copy, modify and
 * redistribute this program, but only under the conditions described
 * in the JMA Open Source License. You should have received a copy of
 * this license along with this program. If not, stop using this
 * program and contact JMA, 2-28-16 Honkomagome, Bunkyo-ku, Tokyo,
 * 113-8621, Japan.
 ********************************************************************
 */
package drugstock.cl;

import drugstock.cmn.PropRead;
import java.awt.*;
import javax.swing.*;

/**
 * Mainクラス
 */

public class DrugStock {

  private final String icon_path = System.getProperty("user.home")
    + "/stock/med_stock.png";
	private boolean packFrame = false;

	/**
	 * ウィンドウを表示し、ソフトを起動します。
	 */
	public DrugStock() {

		MainFrame frame = new MainFrame();
    
		// validate() はサイズを調整する
		// pack() は有効なサイズ情報をレイアウトなどから取得する
		if (packFrame) {
			frame.pack();
		} else {
			frame.validate();
		}
		
		// ウィンドウを中央に配置
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		Dimension frameSize = frame.getSize();
		if (frameSize.height > screenSize.height) {
			frameSize.height = screenSize.height;
		}
		if (frameSize.width > screenSize.width) {
			frameSize.width = screenSize.width;
		}
		frame.setLocation((screenSize.width - frameSize.width) / 2,
		        (screenSize.height - frameSize.height) / 2);
		
		try {
      UIManager.getInstalledLookAndFeels();

      PropRead prop = new PropRead();
      String stock_themes = prop.getProp("themes");

      ImageIcon icon = new ImageIcon(icon_path);
      frame.setIconImage(icon.getImage());

      if (stock_themes == null) {
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
      } else {
        if (stock_themes.equals("") == true) {
          UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } else {
          UIManager.setLookAndFeel(stock_themes);
        }
      } 
      SwingUtilities.updateComponentTreeUI(frame);
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		frame.setVisible(true);
	}

	/**
	 * Main メソッドです。
	 */
	public static void main(String[] args) {
		new DrugStock();
	}
}
