package drugstock.prt;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.FileWriter;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.List;

import drugstock.cmn.PropRead;

final class PrintUtil {
  final static File RED2PS_BIN = new File("/usr/bin/red2ps");
  final static File RED2EMBED_BIN = new File("/usr/bin/red2embed");
  final static String RED2PS = new String("red2ps");
  final static String RED2EMBED = new String("red2embed");
  final static String RED2NONE = new String("none");
  final static String MONPE = new String("monpe");
  final static String LPR = new String("lpr");

  static String getPrintMethod(){
    String printMethod = new String(RED2PS);

    if(RED2PS_BIN.exists()){                                               
      System.out.println("red2ps exists");                    
      printMethod = RED2PS;
    } else {
      if(RED2EMBED_BIN.exists()){                                               
        System.out.println("red2embed exists");                    
        printMethod = RED2EMBED;
      } else {
        System.out.println("red2ps and red2embed not found");                    
        printMethod = RED2NONE;
      }              
    }              
    return printMethod;
  }

  static void printForm(final String formNamePre, final String pageFileName) throws IOException {
    String printMethod = PrintUtil.getPrintMethod();
    String formName = new String("");

    final List commandList_Red = new ArrayList();
    final List commandList_Monpe = new ArrayList();
    final List commandList_Print = new ArrayList();

    final PropRead prop = new PropRead();
    String printerInfo = prop.getPropPrinter("printer_info");
    String printCharSet = prop.getProp("print_charset");

    {
      if (printMethod.equals(RED2PS)) {
        formName = formNamePre.replaceAll("/frm/","/frm_46/");
        System.out.println("frm -> frm_46:"+formName);

        commandList_Red.add(RED2PS);
        commandList_Red.add(formName);
        commandList_Red.add(pageFileName+".tmp");

      } else if (printMethod.equals(RED2EMBED)) {
        formName = formNamePre.replaceAll("/frm/","/frm_47/");
        System.out.println("frm -> frm_47:"+formName);

        commandList_Red.add(RED2EMBED);
        commandList_Red.add(formName);
        commandList_Red.add(pageFileName+".tmp");
        commandList_Red.add("-o");
        commandList_Red.add(pageFileName+".tmp.red");

        commandList_Monpe.add(MONPE);
        commandList_Monpe.add(pageFileName+".tmp.red");
        commandList_Monpe.add("-e");
        commandList_Monpe.add(pageFileName+".pdf");

        commandList_Print.add(LPR);
        commandList_Print.add(pageFileName+".pdf");

      } else {
        printMethod = RED2NONE;
      }

      System.out.println("Setting_Charset: "+printCharSet);
      String comv_cmd = "";
      String to_CharSet = "";
      String from_CharSet = "UTF-8";

      if (printCharSet != null) {
        printCharSet = printCharSet.trim();
        if (printCharSet.length() > 0) {
          if (printCharSet.equals("UTF-8") || printCharSet.equals("UTF8")) {
            if (printMethod.equals(RED2PS)) {
              commandList_Red.add("-u");
            }
            to_CharSet = "EUC-JISX0213";
          } else {
            to_CharSet = "EUC-JP";
          }
        }
      } else {
        to_CharSet = "EUC-JP";
      }

      comv_cmd = "iconv -f "+from_CharSet+" -t "+to_CharSet+" ";
      comv_cmd = comv_cmd+pageFileName+" -o "+pageFileName+".tmp";

      Process process = Runtime.getRuntime().exec(comv_cmd);
      InputStream gis = process.getInputStream();
      InputStream ges = process.getErrorStream();

      while (true) {
        try {
          if (process.exitValue() >= 1) {
            throw new IOException();
          }
          break;
        } catch (IllegalThreadStateException e) {
          break;
        }
      }
    }

    if (printerInfo != null) {
      printerInfo = printerInfo.trim();
      if (printerInfo.length() > 0) {
        if (printMethod.equals(RED2PS)) {
          commandList_Red.add("-p");
          commandList_Red.add(printerInfo);
        } else if (printMethod.equals(RED2EMBED)) {
          commandList_Print.add("-P");
          commandList_Print.add(printerInfo);
        }
      }
    }

    final Runtime runtime = Runtime.getRuntime();

    if (printMethod.equals(RED2PS)) {
      System.err.println("Executing: " + commandList_Red);

      final Process process = runtime.exec((String[])commandList_Red.toArray(new String[] {}));
      final InputStream is_red = process.getInputStream();
      while (true) {
        try {
          process.exitValue();
          break;
        } catch (IllegalThreadStateException e) {
        }
      }
    } else if (printMethod.equals(RED2EMBED)) {
      System.err.println("Executing: " + commandList_Red);
      System.err.println("Executing: " + commandList_Monpe);
      System.err.println("Executing: " + commandList_Print);

      final Process process_red = runtime.exec((String[])commandList_Red.toArray(new String[] {}));
      final InputStream is_red = process_red.getInputStream();
      while (true) {
        try {
          process_red.exitValue();
          break;
        } catch (IllegalThreadStateException e) {
        }
      }

      final Process process_monpe = runtime.exec((String[])commandList_Monpe.toArray(new String[] {}));
      final InputStream is_monpe = process_monpe.getInputStream();
      while (true) {
        try {
          process_monpe.exitValue();
          break;
        } catch (IllegalThreadStateException e) {
        }
      }

      final Process process_print = runtime.exec((String[])commandList_Print.toArray(new String[] {}));
      final InputStream is_print = process_print.getInputStream();
      while (true) {
        try {
          process_print.exitValue();
          break;
        } catch (IllegalThreadStateException e) {
        }
      }
    } else {
      System.out.println("printMethod none");
    }
  }
}
